@@ -1,7 +1,10 @@
 use crate::{
     channel::ReactionType,
     guild::member::{Member, OptionalMemberDeserializer},
-    id::{ChannelId, GuildId, MessageId, UserId},
+    id::{
+        marker::{ChannelMarker, GuildMarker, MessageMarker, UserMarker},
+        Id,
+    },
 };
 use serde::{
     de::{Deserializer, Error as DeError, IgnoredAny, MapAccess, Visitor},
@@ -11,12 +14,12 @@ use std::fmt::{Formatter, Result as FmtResult};
 
 #[derive(Clone, Debug, Eq, Hash, PartialEq, Serialize)]
 pub struct Reaction {
-    pub channel_id: ChannelId,
+    pub channel_id: Id<ChannelMarker>,
     pub emoji: ReactionType,
-    pub guild_id: Option<GuildId>,
+    pub guild_id: Option<Id<GuildMarker>>,
     pub member: Option<Member>,
-    pub message_id: MessageId,
-    pub user_id: UserId,
+    pub message_id: Id<MessageMarker>,
+    pub user_id: Id<UserMarker>,
 }
 
 #[derive(Debug, Deserialize)]
@@ -111,8 +114,7 @@ impl<'de> Visitor<'de> for ReactionVisitor {
                         return Err(DeError::duplicate_field("member"));
                     }
 
-                    let deserializer =
-                        OptionalMemberDeserializer::new(GuildId::new(1).expect("non zero"));
+                    let deserializer = OptionalMemberDeserializer::new(Id::new(1));
 
                     member = map.next_value_seed(deserializer)?;
                 }
@@ -180,7 +182,8 @@ mod tests {
     use crate::{
         datetime::{Timestamp, TimestampParseError},
         guild::Member,
-        id::{ChannelId, GuildId, MessageId, RoleId, UserId},
+        id::Id,
+        test::image_hash,
         user::User,
     };
     use serde_test::Token;
@@ -192,31 +195,31 @@ mod tests {
         let joined_at = Timestamp::from_str("2020-01-01T00:00:00.000000+00:00")?;
 
         let value = Reaction {
-            channel_id: ChannelId::new(2).expect("non zero"),
+            channel_id: Id::new(2),
             emoji: ReactionType::Unicode {
                 name: "a".to_owned(),
             },
-            guild_id: Some(GuildId::new(1).expect("non zero")),
+            guild_id: Some(Id::new(1)),
             member: Some(Member {
                 avatar: None,
                 communication_disabled_until: None,
                 deaf: false,
-                guild_id: GuildId::new(1).expect("non zero"),
+                guild_id: Id::new(1),
                 joined_at,
                 mute: false,
                 nick: Some("typing".to_owned()),
                 pending: false,
                 premium_since: None,
-                roles: vec![RoleId::new(5).expect("non zero")],
+                roles: vec![Id::new(5)],
                 user: User {
                     accent_color: None,
-                    avatar: Some("aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa".to_owned()),
+                    avatar: Some(image_hash::AVATAR),
                     banner: None,
                     bot: false,
                     discriminator: 1,
                     email: None,
                     flags: None,
-                    id: UserId::new(4).expect("non zero"),
+                    id: Id::new(4),
                     locale: None,
                     mfa_enabled: None,
                     name: "test".to_owned(),
@@ -226,8 +229,8 @@ mod tests {
                     verified: None,
                 },
             }),
-            message_id: MessageId::new(3).expect("non zero"),
-            user_id: UserId::new(4).expect("non zero"),
+            message_id: Id::new(3),
+            user_id: Id::new(4),
         };
 
         serde_test::assert_tokens(
@@ -238,7 +241,7 @@ mod tests {
                     len: 6,
                 },
                 Token::Str("channel_id"),
-                Token::NewtypeStruct { name: "ChannelId" },
+                Token::NewtypeStruct { name: "Id" },
                 Token::Str("2"),
                 Token::Str("emoji"),
                 Token::Struct {
@@ -250,7 +253,7 @@ mod tests {
                 Token::StructEnd,
                 Token::Str("guild_id"),
                 Token::Some,
-                Token::NewtypeStruct { name: "GuildId" },
+                Token::NewtypeStruct { name: "Id" },
                 Token::Str("1"),
                 Token::Str("member"),
                 Token::Some,
@@ -263,7 +266,7 @@ mod tests {
                 Token::Str("deaf"),
                 Token::Bool(false),
                 Token::Str("guild_id"),
-                Token::NewtypeStruct { name: "GuildId" },
+                Token::NewtypeStruct { name: "Id" },
                 Token::Str("1"),
                 Token::Str("joined_at"),
                 Token::Str("2020-01-01T00:00:00.000000+00:00"),
@@ -276,7 +279,7 @@ mod tests {
                 Token::Bool(false),
                 Token::Str("roles"),
                 Token::Seq { len: Some(1) },
-                Token::NewtypeStruct { name: "RoleId" },
+                Token::NewtypeStruct { name: "Id" },
                 Token::Str("5"),
                 Token::SeqEnd,
                 Token::Str("user"),
@@ -288,7 +291,7 @@ mod tests {
                 Token::None,
                 Token::Str("avatar"),
                 Token::Some,
-                Token::Str("aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa"),
+                Token::Str(image_hash::AVATAR_INPUT),
                 Token::Str("banner"),
                 Token::None,
                 Token::Str("bot"),
@@ -296,17 +299,17 @@ mod tests {
                 Token::Str("discriminator"),
                 Token::Str("0001"),
                 Token::Str("id"),
-                Token::NewtypeStruct { name: "UserId" },
+                Token::NewtypeStruct { name: "Id" },
                 Token::Str("4"),
                 Token::Str("username"),
                 Token::Str("test"),
                 Token::StructEnd,
                 Token::StructEnd,
                 Token::Str("message_id"),
-                Token::NewtypeStruct { name: "MessageId" },
+                Token::NewtypeStruct { name: "Id" },
                 Token::Str("3"),
                 Token::Str("user_id"),
-                Token::NewtypeStruct { name: "UserId" },
+                Token::NewtypeStruct { name: "Id" },
                 Token::Str("4"),
                 Token::StructEnd,
             ],
@@ -318,14 +321,14 @@ mod tests {
     #[test]
     fn test_reaction_without_member() {
         let value = Reaction {
-            channel_id: ChannelId::new(2).expect("non zero"),
+            channel_id: Id::new(2),
             emoji: ReactionType::Unicode {
                 name: "a".to_owned(),
             },
             guild_id: None,
             member: None,
-            message_id: MessageId::new(3).expect("non zero"),
-            user_id: UserId::new(4).expect("non zero"),
+            message_id: Id::new(3),
+            user_id: Id::new(4),
         };
 
         serde_test::assert_tokens(
@@ -336,7 +339,7 @@ mod tests {
                     len: 6,
                 },
                 Token::Str("channel_id"),
-                Token::NewtypeStruct { name: "ChannelId" },
+                Token::NewtypeStruct { name: "Id" },
                 Token::Str("2"),
                 Token::Str("emoji"),
                 Token::Struct {
@@ -351,10 +354,10 @@ mod tests {
                 Token::Str("member"),
                 Token::None,
                 Token::Str("message_id"),
-                Token::NewtypeStruct { name: "MessageId" },
+                Token::NewtypeStruct { name: "Id" },
                 Token::Str("3"),
                 Token::Str("user_id"),
-                Token::NewtypeStruct { name: "UserId" },
+                Token::NewtypeStruct { name: "Id" },
                 Token::Str("4"),
                 Token::StructEnd,
             ],
