@@ -22,6 +22,7 @@ pub enum EventType {
     GuildDelete,
     GuildEmojisUpdate,
     GuildIntegrationsUpdate,
+    GuildStickersUpdate,
     GuildUpdate,
     IntegrationCreate,
     IntegrationDelete,
@@ -97,6 +98,7 @@ impl EventType {
             Self::GuildDelete => Some("GUILD_DELETE"),
             Self::GuildEmojisUpdate => Some("GUILD_EMOJIS_UPDATE"),
             Self::GuildIntegrationsUpdate => Some("GUILD_INTEGRATIONS_UPDATE"),
+            Self::GuildStickersUpdate => Some("GUILD_STICKERS_UPDATE"),
             Self::GuildUpdate => Some("GUILD_UPDATE"),
             Self::IntegrationCreate => Some("INTEGRATION_CREATE"),
             Self::IntegrationDelete => Some("INTEGRATION_DELETE"),
