@@ -1,6 +1,9 @@
 use crate::{
     channel::thread::{ThreadMember, ThreadMemberIntermediary},
-    id::{ChannelId, GuildId, UserId},
+    id::{
+        marker::{ChannelMarker, GuildMarker, UserMarker},
+        Id,
+    },
 };
 use serde::{
     de::{value::MapAccessDeserializer, MapAccess, Visitor},
@@ -17,12 +20,12 @@ pub struct ThreadMembersUpdate {
     /// [`member`]: ThreadMember::member
     #[serde(default)]
     pub added_members: Vec<ThreadMember>,
-    pub guild_id: GuildId,
-    pub id: ChannelId,
+    pub guild_id: Id<GuildMarker>,
+    pub id: Id<ChannelMarker>,
     /// Max value of 50.
     pub member_count: u8,
     #[serde(default)]
-    pub removed_member_ids: Vec<UserId>,
+    pub removed_member_ids: Vec<Id<UserMarker>>,
 }
 
 impl<'de> Deserialize<'de> for ThreadMembersUpdate {
@@ -36,12 +39,12 @@ struct ThreadMembersUpdateIntermediary {
     /// ThreadMembers without the guild ID.
     #[serde(default)]
     pub added_members: Vec<ThreadMemberIntermediary>,
-    pub guild_id: GuildId,
-    pub id: ChannelId,
+    pub guild_id: Id<GuildMarker>,
+    pub id: Id<ChannelMarker>,
     /// Max value of 50.
     pub member_count: u8,
     #[serde(default)]
-    pub removed_member_ids: Vec<UserId>,
+    pub removed_member_ids: Vec<Id<UserMarker>>,
 }
 
 impl ThreadMembersUpdateIntermediary {
@@ -90,7 +93,8 @@ mod tests {
             Activity, ActivityEmoji, ActivityType, ClientStatus, Presence, Status, UserOrId,
         },
         guild::Member,
-        id::{ChannelId, GuildId, UserId},
+        id::Id,
+        test::image_hash,
         user::User,
     };
     use serde_test::Token;
@@ -106,10 +110,10 @@ mod tests {
         let premium_since = Timestamp::from_str(PREMIUM_SINCE).expect("timestamp error");
 
         let member = Member {
-            avatar: Some("guild avatar".to_owned()),
+            avatar: Some(image_hash::AVATAR),
             communication_disabled_until: None,
             deaf: false,
-            guild_id: GuildId::new(2).expect("non zero"),
+            guild_id: Id::new(2),
             joined_at,
             mute: true,
             nick: Some("twilight".to_owned()),
@@ -124,7 +128,7 @@ mod tests {
                 discriminator: 1,
                 email: None,
                 flags: None,
-                id: UserId::new(3).expect("non zero"),
+                id: Id::new(3),
                 locale: None,
                 mfa_enabled: None,
                 name: "twilight".to_owned(),
@@ -164,11 +168,9 @@ mod tests {
                 mobile: None,
                 web: None,
             },
-            guild_id: GuildId::new(2).expect("non zero"),
+            guild_id: Id::new(2),
             status: Status::Online,
-            user: UserOrId::UserId {
-                id: UserId::new(3).expect("non zero"),
-            },
+            user: UserOrId::UserId { id: Id::new(3) },
         };
 
         let join_timestamp = Timestamp::from_str(JOIN_TIMESTAMP).expect("timestamp error");
@@ -176,14 +178,14 @@ mod tests {
         let value = ThreadMembersUpdate {
             added_members: vec![ThreadMember {
                 flags: 1,
-                id: Some(ChannelId::new(123).expect("non zero")),
+                id: Some(Id::new(123)),
                 join_timestamp,
                 member: Some(member),
                 presence: Some(presence),
-                user_id: Some(UserId::new(3).expect("non zero")),
+                user_id: Some(Id::new(3)),
             }],
-            guild_id: GuildId::new(2).expect("non zero"),
-            id: ChannelId::new(4).expect("non zero"),
+            guild_id: Id::new(2),
+            id: Id::new(4),
             member_count: 8,
             removed_member_ids: vec![],
         };
@@ -217,7 +219,7 @@ mod tests {
                 },
                 Token::Str("avatar"),
                 Token::Some,
-                Token::Str("guild avatar"),
+                Token::Str(image_hash::AVATAR_INPUT),
                 Token::Str("communication_disabled_until"),
                 Token::None,
                 Token::Str("deaf"),
