@@ -10,7 +10,8 @@ mod tests {
     use crate::{
         datetime::{Timestamp, TimestampParseError},
         guild::Member,
-        id::{GuildId, RoleId, UserId},
+        id::Id,
+        test::image_hash,
         user::User,
     };
     use serde_test::Token;
@@ -24,20 +25,20 @@ mod tests {
         let value = VoiceStateUpdate(VoiceState {
             channel_id: None,
             deaf: false,
-            guild_id: Some(GuildId::new(1).expect("non zero")),
+            guild_id: Some(Id::new(1)),
             member: Some(Member {
                 avatar: None,
                 communication_disabled_until: None,
                 deaf: false,
-                guild_id: GuildId::new(1).expect("non zero"),
+                guild_id: Id::new(1),
                 joined_at,
                 mute: false,
                 nick: None,
                 pending: false,
                 premium_since: None,
-                roles: vec![RoleId::new(4).expect("non zero")],
+                roles: vec![Id::new(4)],
                 user: User {
-                    id: UserId::new(1).expect("non zero"),
+                    id: Id::new(1),
                     accent_color: None,
                     avatar: None,
                     banner: None,
@@ -62,7 +63,7 @@ mod tests {
             session_id: "a".to_owned(),
             suppress: false,
             token: None,
-            user_id: UserId::new(1).expect("non zero"),
+            user_id: Id::new(1),
             request_to_speak_timestamp: None,
         });
 
@@ -82,7 +83,7 @@ mod tests {
                 Token::Bool(false),
                 Token::Str("guild_id"),
                 Token::Some,
-                Token::NewtypeStruct { name: "GuildId" },
+                Token::NewtypeStruct { name: "Id" },
                 Token::Str("1"),
                 Token::Str("member"),
                 Token::Some,
@@ -95,7 +96,7 @@ mod tests {
                 Token::Str("deaf"),
                 Token::Bool(false),
                 Token::Str("guild_id"),
-                Token::NewtypeStruct { name: "GuildId" },
+                Token::NewtypeStruct { name: "Id" },
                 Token::Str("1"),
                 Token::Str("joined_at"),
                 Token::Str("2021-09-19T17:30:45.000000+00:00"),
@@ -107,7 +108,7 @@ mod tests {
                 Token::Bool(false),
                 Token::Str("roles"),
                 Token::Seq { len: Some(1) },
-                Token::NewtypeStruct { name: "RoleId" },
+                Token::NewtypeStruct { name: "Id" },
                 Token::Str("4"),
                 Token::SeqEnd,
                 Token::Str("user"),
@@ -126,7 +127,7 @@ mod tests {
                 Token::Str("discriminator"),
                 Token::Str("0909"),
                 Token::Str("id"),
-                Token::NewtypeStruct { name: "UserId" },
+                Token::NewtypeStruct { name: "Id" },
                 Token::Str("1"),
                 Token::Str("username"),
                 Token::Str("foo"),
@@ -147,7 +148,7 @@ mod tests {
                 Token::Str("suppress"),
                 Token::Bool(false),
                 Token::Str("user_id"),
-                Token::NewtypeStruct { name: "UserId" },
+                Token::NewtypeStruct { name: "Id" },
                 Token::Str("1"),
                 Token::Str("request_to_speak_timestamp"),
                 Token::None,
@@ -165,25 +166,22 @@ mod tests {
         let value = VoiceStateUpdate(VoiceState {
             channel_id: None,
             deaf: false,
-            guild_id: Some(GuildId::new(999_999).expect("non zero")),
+            guild_id: Some(Id::new(999_999)),
             member: Some(Member {
                 avatar: None,
                 communication_disabled_until: None,
                 deaf: false,
-                guild_id: GuildId::new(999_999).expect("non zero"),
+                guild_id: Id::new(999_999),
                 joined_at,
                 mute: false,
                 nick: Some("Twilight".to_string()),
                 pending: false,
                 premium_since: None,
-                roles: vec![
-                    RoleId::new(123).expect("non zero"),
-                    RoleId::new(124).expect("non zero"),
-                ],
+                roles: vec![Id::new(123), Id::new(124)],
                 user: User {
-                    id: UserId::new(1_234_123_123_123).expect("non zero"),
+                    id: Id::new(1_234_123_123_123),
                     accent_color: None,
-                    avatar: Some("a21312321231236060dfe562c".to_string()),
+                    avatar: Some(image_hash::AVATAR),
                     banner: None,
                     bot: false,
                     discriminator: 4242,
@@ -206,7 +204,7 @@ mod tests {
             session_id: "asdasdas1da98da2b3ab3a".to_owned(),
             suppress: false,
             token: None,
-            user_id: UserId::new(123_213).expect("non zero"),
+            user_id: Id::new(123_213),
             request_to_speak_timestamp: Some(request_to_speak_timestamp),
         });
 
@@ -230,7 +228,7 @@ mod tests {
                 Token::Bool(false),
                 Token::Str("guild_id"),
                 Token::Some,
-                Token::NewtypeStruct { name: "GuildId" },
+                Token::NewtypeStruct { name: "Id" },
                 Token::Str("999999"),
                 Token::Str("member"),
                 Token::Some,
@@ -253,9 +251,9 @@ mod tests {
                 Token::Bool(false),
                 Token::Str("roles"),
                 Token::Seq { len: Some(2) },
-                Token::NewtypeStruct { name: "RoleId" },
+                Token::NewtypeStruct { name: "Id" },
                 Token::Str("123"),
-                Token::NewtypeStruct { name: "RoleId" },
+                Token::NewtypeStruct { name: "Id" },
                 Token::Str("124"),
                 Token::SeqEnd,
                 Token::Str("user"),
@@ -267,7 +265,7 @@ mod tests {
                 Token::None,
                 Token::Str("avatar"),
                 Token::Some,
-                Token::Str("a21312321231236060dfe562c"),
+                Token::Str(image_hash::AVATAR_INPUT),
                 Token::Str("banner"),
                 Token::None,
                 Token::Str("bot"),
@@ -275,7 +273,7 @@ mod tests {
                 Token::Str("discriminator"),
                 Token::Str("4242"),
                 Token::Str("id"),
-                Token::NewtypeStruct { name: "UserId" },
+                Token::NewtypeStruct { name: "Id" },
                 Token::Str("1234123123123"),
                 Token::Str("username"),
                 Token::Str("Twilight Sparkle"),
@@ -296,7 +294,7 @@ mod tests {
                 Token::Str("suppress"),
                 Token::Bool(false),
                 Token::Str("user_id"),
-                Token::NewtypeStruct { name: "UserId" },
+                Token::NewtypeStruct { name: "Id" },
                 Token::Str("123213"),
                 Token::Str("request_to_speak_timestamp"),
                 Token::Some,
