@@ -21,7 +21,10 @@ pub use self::{
 };
 
 use crate::{
-    id::{GuildId, UserId},
+    id::{
+        marker::{GuildMarker, UserMarker},
+        Id,
+    },
     user::User,
 };
 use serde::{
@@ -37,7 +40,7 @@ pub struct Presence {
     #[serde(default)]
     pub activities: Vec<Activity>,
     pub client_status: ClientStatus,
-    pub guild_id: GuildId,
+    pub guild_id: Id<GuildMarker>,
     pub status: Status,
     pub user: UserOrId,
 }
@@ -46,12 +49,12 @@ pub struct Presence {
 #[serde(untagged)]
 pub enum UserOrId {
     User(User),
-    UserId { id: UserId },
+    UserId { id: Id<UserMarker> },
 }
 
 impl UserOrId {
     /// ID of the inner object.
-    pub const fn id(&self) -> UserId {
+    pub const fn id(&self) -> Id<UserMarker> {
         match self {
             UserOrId::User(u) => u.id,
             UserOrId::UserId { id } => *id,
@@ -64,7 +67,7 @@ pub struct PresenceIntermediary {
     #[serde(default)]
     pub activities: Vec<Activity>,
     pub client_status: ClientStatus,
-    pub guild_id: Option<GuildId>,
+    pub guild_id: Option<Id<GuildMarker>>,
     pub nick: Option<String>,
     pub status: Status,
     pub user: UserOrId,
@@ -72,7 +75,7 @@ pub struct PresenceIntermediary {
 
 impl PresenceIntermediary {
     /// Inject guild ID into presence if not already present.
-    pub fn into_presence(self, guild_id: GuildId) -> Presence {
+    pub fn into_presence(self, guild_id: Id<GuildMarker>) -> Presence {
         Presence {
             activities: self.activities,
             client_status: self.client_status,
@@ -83,7 +86,7 @@ impl PresenceIntermediary {
     }
 }
 
-struct PresenceVisitor(GuildId);
+struct PresenceVisitor(Id<GuildMarker>);
 
 impl<'de> Visitor<'de> for PresenceVisitor {
     type Value = Presence;
@@ -107,12 +110,12 @@ impl<'de> Visitor<'de> for PresenceVisitor {
 }
 
 #[derive(Clone, Debug, Eq, PartialEq)]
-pub struct PresenceDeserializer(GuildId);
+pub struct PresenceDeserializer(Id<GuildMarker>);
 
 impl PresenceDeserializer {
     /// Create a new deserializer for a presence when you know the guild ID but
     /// the payload probably doesn't contain it.
-    pub const fn new(guild_id: GuildId) -> Self {
+    pub const fn new(guild_id: Id<GuildMarker>) -> Self {
         Self(guild_id)
     }
 }
@@ -126,17 +129,17 @@ impl<'de> DeserializeSeed<'de> for PresenceDeserializer {
 }
 
 #[derive(Clone, Debug, Eq, PartialEq)]
-pub struct PresenceListDeserializer(GuildId);
+pub struct PresenceListDeserializer(Id<GuildMarker>);
 
 impl PresenceListDeserializer {
     /// Create a new deserializer for a map of presences when you know the
     /// Guild ID but the payload probably doesn't contain it.
-    pub const fn new(guild_id: GuildId) -> Self {
+    pub const fn new(guild_id: Id<GuildMarker>) -> Self {
         Self(guild_id)
     }
 }
 
-struct PresenceListDeserializerVisitor(GuildId);
+struct PresenceListDeserializerVisitor(Id<GuildMarker>);
 
 impl<'de> Visitor<'de> for PresenceListDeserializerVisitor {
     type Value = Vec<Presence>;
@@ -170,7 +173,7 @@ mod tests {
         Activity, ActivityEmoji, ActivityType, ClientStatus, Presence, PresenceListDeserializer,
         Status, UserOrId,
     };
-    use crate::id::{GuildId, UserId};
+    use crate::id::Id;
     use serde::de::DeserializeSeed;
     use serde_json::Deserializer;
     use serde_test::Token;
@@ -207,11 +210,9 @@ mod tests {
                 mobile: None,
                 web: None,
             },
-            guild_id: GuildId::new(2).expect("non zero"),
+            guild_id: Id::new(2),
             status: Status::Online,
-            user: UserOrId::UserId {
-                id: UserId::new(1).expect("non zero"),
-            },
+            user: UserOrId::UserId { id: Id::new(1) },
         };
 
         serde_test::assert_de_tokens(
@@ -230,7 +231,7 @@ mod tests {
                 Token::Str("1"),
                 Token::StructEnd,
                 Token::Str("guild_id"),
-                Token::NewtypeStruct { name: "GuildId" },
+                Token::NewtypeStruct { name: "Id" },
                 Token::Str("2"),
                 Token::Str("status"),
                 Token::Enum { name: "Status" },
@@ -311,15 +312,13 @@ mod tests {
                 mobile: None,
                 web: None,
             },
-            guild_id: GuildId::new(2).expect("non zero"),
+            guild_id: Id::new(2),
             status: Status::Online,
-            user: UserOrId::UserId {
-                id: UserId::new(1).expect("non zero"),
-            },
+            user: UserOrId::UserId { id: Id::new(1) },
         }]);
 
         let mut json_deserializer = Deserializer::from_str(input);
-        let deserializer = PresenceListDeserializer::new(GuildId::new(2).expect("non zero"));
+        let deserializer = PresenceListDeserializer::new(Id::new(2));
         let actual = deserializer.deserialize(&mut json_deserializer).unwrap();
 
         assert_eq!(actual, expected);
