@@ -15,6 +15,7 @@ use crate::{
         },
         Id,
     },
+    util::ImageHash,
 };
 use serde::{Deserialize, Serialize};
 
@@ -318,6 +319,15 @@ pub enum AuditLogChange {
         #[serde(rename = "old_value", skip_serializing_if = "Option::is_none")]
         old: Option<Id<GenericMarker>>,
     },
+    /// Hash of a guild scheduled event cover.
+    ImageHash {
+        /// New hash of a guild's icon.
+        #[serde(rename = "new_value", skip_serializing_if = "Option::is_none")]
+        new: Option<ImageHash>,
+        /// Old hash of a guild's icon.
+        #[serde(rename = "old_value", skip_serializing_if = "Option::is_none")]
+        old: Option<ImageHash>,
+    },
     /// Invitable state of a private thread.
     Invitable {
         /// New threads invitable state.
@@ -747,6 +757,7 @@ impl AuditLogChange {
             Self::Hoist { .. } => AuditLogChangeKey::Hoist,
             Self::IconHash { .. } => AuditLogChangeKey::IconHash,
             Self::Id { .. } => AuditLogChangeKey::Id,
+            Self::ImageHash { .. } => AuditLogChangeKey::ImageHash,
             Self::Invitable { .. } => AuditLogChangeKey::Invitable,
             Self::InviterId { .. } => AuditLogChangeKey::InviterId,
             Self::Location { .. } => AuditLogChangeKey::Location,
@@ -825,6 +836,7 @@ mod tests {
     assert_fields!(AuditLogChange::Hoist: new, old);
     assert_fields!(AuditLogChange::IconHash: new, old);
     assert_fields!(AuditLogChange::Id: new);
+    assert_fields!(AuditLogChange::ImageHash: new, old);
     assert_fields!(AuditLogChange::Invitable: new, old);
     assert_fields!(AuditLogChange::InviterId: new);
     assert_fields!(AuditLogChange::MaxAge: new);
