@@ -75,6 +75,8 @@ pub enum AuditLogChangeKey {
     IconHash,
     /// ID of an entity.
     Id,
+    /// Hash of a guild scheduled event cover.
+    ImageHash,
     /// Invitable state of a private thread.
     Invitable,
     /// ID of the user who created an invite.
@@ -210,6 +212,7 @@ impl AuditLogChangeKey {
             Self::Hoist => "hoist",
             Self::IconHash => "icon_hash",
             Self::Id => "id",
+            Self::ImageHash => "image_hash",
             Self::Invitable => "invitable",
             Self::InviterId => "inviter_id",
             Self::Location => "location",
@@ -328,6 +331,7 @@ mod tests {
         assert_eq!("hoist", AuditLogChangeKey::Hoist.name());
         assert_eq!("icon_hash", AuditLogChangeKey::IconHash.name());
         assert_eq!("id", AuditLogChangeKey::Id.name());
+        assert_eq!("image_hash", AuditLogChangeKey::ImageHash.name());
         assert_eq!("invitable", AuditLogChangeKey::Invitable.name());
         assert_eq!("inviter_id", AuditLogChangeKey::InviterId.name());
         assert_eq!("max_age", AuditLogChangeKey::MaxAge.name());
@@ -547,6 +551,13 @@ mod tests {
                 variant: "id",
             }],
         );
+        serde_test::assert_tokens(
+            &AuditLogChangeKey::ImageHash,
+            &[Token::UnitVariant {
+                name: "AuditLogChangeKey",
+                variant: "image_hash",
+            }],
+        );
         serde_test::assert_tokens(
             &AuditLogChangeKey::Invitable,
             &[Token::UnitVariant {
