@@ -1,4 +1,7 @@
-use crate::id::{ChannelId, EmojiId};
+use crate::id::{
+    marker::{ChannelMarker, EmojiMarker},
+    Id,
+};
 use serde::{Deserialize, Serialize};
 
 #[derive(Clone, Debug, Deserialize, Eq, Hash, PartialEq, Serialize)]
@@ -12,18 +15,19 @@ pub struct WelcomeScreen {
 #[derive(Clone, Debug, Deserialize, Eq, Hash, PartialEq, Serialize)]
 pub struct WelcomeScreenChannel {
     /// ID of the channel.
-    pub channel_id: ChannelId,
+    pub channel_id: Id<ChannelMarker>,
     /// Description of the channel.
     pub description: String,
     /// ID of the emoji if the emoji is custom.
-    pub emoji_id: Option<EmojiId>,
+    pub emoji_id: Option<Id<EmojiMarker>>,
     /// Emoji's name if it is custom, or the unicode character.
     pub emoji_name: Option<String>,
 }
 
 #[cfg(test)]
 mod tests {
-    use super::{ChannelId, EmojiId, WelcomeScreen, WelcomeScreenChannel};
+    use super::{WelcomeScreen, WelcomeScreenChannel};
+    use crate::id::Id;
     use serde_test::Token;
 
     #[test]
@@ -32,15 +36,15 @@ mod tests {
             description: Some("welcome description".to_owned()),
             welcome_channels: vec![
                 WelcomeScreenChannel {
-                    channel_id: ChannelId::new(123).expect("non zero"),
+                    channel_id: Id::new(123),
                     description: "channel description".to_owned(),
                     emoji_id: None,
                     emoji_name: Some("\u{1f352}".to_owned()),
                 },
                 WelcomeScreenChannel {
-                    channel_id: ChannelId::new(456).expect("non zero"),
+                    channel_id: Id::new(456),
                     description: "custom description".to_owned(),
-                    emoji_id: Some(EmojiId::new(789).expect("non zero")),
+                    emoji_id: Some(Id::new(789)),
                     emoji_name: Some("custom_name".to_owned()),
                 },
             ],
@@ -63,7 +67,7 @@ mod tests {
                     len: 4,
                 },
                 Token::Str("channel_id"),
-                Token::NewtypeStruct { name: "ChannelId" },
+                Token::NewtypeStruct { name: "Id" },
                 Token::Str("123"),
                 Token::Str("description"),
                 Token::Str("channel description"),
@@ -78,13 +82,13 @@ mod tests {
                     len: 4,
                 },
                 Token::Str("channel_id"),
-                Token::NewtypeStruct { name: "ChannelId" },
+                Token::NewtypeStruct { name: "Id" },
                 Token::Str("456"),
                 Token::Str("description"),
                 Token::Str("custom description"),
                 Token::Str("emoji_id"),
                 Token::Some,
-                Token::NewtypeStruct { name: "EmojiId" },
+                Token::NewtypeStruct { name: "Id" },
                 Token::Str("789"),
                 Token::Str("emoji_name"),
                 Token::Some,
